@@ -1,6 +1,6 @@
 var interfacecom_1_1sun_1_1star_1_1frame_1_1XFrame2 =
 [
-    [ "XStatusIndicatorFactory", "interfacecom_1_1sun_1_1star_1_1frame_1_1XFrame2.html#a0700064fe1138da0e68a0cc0fbe7eeaa", null ],
+    [ "com::sun::star::task::XStatusIndicatorFactory", "interfacecom_1_1sun_1_1star_1_1frame_1_1XFrame2.html#a0700064fe1138da0e68a0cc0fbe7eeaa", null ],
     [ "XDispatchInformationProvider", "interfacecom_1_1sun_1_1star_1_1frame_1_1XFrame2.html#a08d2d67289e2ca5eb5c46b9c3514515d", null ],
     [ "XDispatchProvider", "interfacecom_1_1sun_1_1star_1_1frame_1_1XFrame2.html#a024de35e0d78cccdbba62395fe776882", null ],
     [ "XDispatchProviderInterception", "interfacecom_1_1sun_1_1star_1_1frame_1_1XFrame2.html#a09306c292b785533b2041afe9a6cf914", null ],
