@@ -1,7 +1,7 @@
 var interfacecom_1_1sun_1_1star_1_1report_1_1XReportControlModel =
 [
-    [ "XContainer", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportControlModel.html#a7a2fee03a55e1e4354eaea94bdaa4e4d", null ],
-    [ "XIndexContainer", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportControlModel.html#a55a8285a19b6ec3383b31ff9d76b099b", null ],
+    [ "com::sun::star::container::XContainer", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportControlModel.html#a7a2fee03a55e1e4354eaea94bdaa4e4d", null ],
+    [ "com::sun::star::container::XIndexContainer", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportControlModel.html#a55a8285a19b6ec3383b31ff9d76b099b", null ],
     [ "XReportComponent", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportControlModel.html#a4eba7fd2195200265b658e6d069dce71", null ],
     [ "XReportControlFormat", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportControlModel.html#a39c83b5aedb8b8453fa6904df5cc3549", null ],
     [ "createFormatCondition", "interfacecom_1_1sun_1_1star_1_1report_1_1XReportControlModel.html#a87347f888d43a001f6624da05138ba6d", null ],
