@@ -1,5 +1,5 @@
 var servicecom_1_1sun_1_1star_1_1form_1_1binding_1_1ListEntrySource =
 [
-    [ "XComponent", "servicecom_1_1sun_1_1star_1_1form_1_1binding_1_1ListEntrySource.html#a3ee2eab6ea072f036a4548a48b0ed454", null ],
+    [ "com::sun::star::lang::XComponent", "servicecom_1_1sun_1_1star_1_1form_1_1binding_1_1ListEntrySource.html#a3ee2eab6ea072f036a4548a48b0ed454", null ],
     [ "XListEntrySource", "servicecom_1_1sun_1_1star_1_1form_1_1binding_1_1ListEntrySource.html#acc2074d97c2b426fc9dcb9b80445a742", null ]
 ];
\ No newline at end of file
